@@ -17,11 +17,17 @@
 #'
 #' @family unweighted wavebands
 #'
-Purple <- function(std="ISO") {
-  if (std=="ISO") {
-    new_waveband(360, 450, wb.name=paste("Purple", std, sep="."), wb.label="Purple")
-  } else if (std=="LandsatOLI" || "RS") {
-    new_waveband(433, 453, wb.name=paste("Purple", std, sep="."), wb.label="Purple")
+Purple <- function(std = "ISO") {
+  if (std == "ISO") {
+    new_waveband(360,
+                 450,
+                 wb.name = paste("Purple", std, sep = "."),
+                 wb.label = "Purple")
+  } else if (std == "LandsatOLI" || "RS") {
+    new_waveband(433,
+                 453,
+                 wb.name = paste("Purple", std, sep = "."),
+                 wb.label = "Purple")
   } else {
     warning("'std' = '", std, "' not implemented.")
     NA
