@@ -19,9 +19,14 @@
 #'
 #' @family unweighted wavebands
 #'
-UV <- function(std="ISO") {
+UV <- function(std = "ISO") {
   if (std %in% c("ISO", "CIE")) {
-    new_waveband(w.low=100, w.high=400, wb.name=paste("UV", std, sep="."), wb.label="UV")
+    new_waveband(
+      w.low = 100,
+      w.high = 400,
+      wb.name = paste("UV", std, sep = "."),
+      wb.label = "UV"
+    )
   } else {
     warning("'std' = '", std, "' not implemented.")
     NA
